from setuptools import setup

setup(name='ftThanos',
version="0.0.66",
description="A client for 66 API",
author="Thanos 66",
author_email="thanos@66paris.fr",
packages=["ftThanos"],
install_requires=["requests","python-dotenv"],
)
